@@ -1,6 +1,6 @@
 package App::ansicolumn;
 
-our $VERSION = "1.15";
+our $VERSION = "1.16";
 
 use v5.14;
 use warnings;
@@ -37,7 +37,7 @@ use Getopt::EX::Hashed; {
     has output_separator    => ' =s o    ' , default => '  ' ;
     has document            => '    D    ' ;
     has page                => ' :i P    ' , min => 0;
-    has pane                => ' =i C    ' , min => 1, default => 0 ;
+    has pane                => ' =s C    ' , default => 0 ;
     has pane_width          => ' =s S pw ' , min => 1;
     has widen               => ' !  W    ' ;
     has paragraph           => ' !  p    ' ;
@@ -70,6 +70,13 @@ use Getopt::EX::Hashed; {
     has '+fillup'    => any => [ qw(pane page none), '' ] ;
     has '+ambiguous' => any => [ qw(wide narrow) ] ;
 
+    # for run-time use
+    has span                => ;
+    has panes               => ;
+    has border_height       => ;
+
+    Getopt::EX::Hashed->configure( DEFAULT => [] );
+
     has '+help' => action => sub {
 	pod2usage
 	    -verbose  => 99,
@@ -81,12 +88,38 @@ use Getopt::EX::Hashed; {
 	exit;
     };
 
-    # for run-time use
-    has span                => ;
-    has panes               => ;
-    has border_height       => ;
+    ### RPN calc for --height, --width, --pane, --pane-width
+    has [ qw(+height +width +pane +pane_width) ] => action => sub {
+	my $obj = $_;
+	my($name, $val) = @_;
+	$obj->{$name} = $val !~ /\D/ ? $val : do {
+	    my $init = $name =~ /height/ ? $obj->term_height : $obj->term_width;
+	    rpn_calc($init, $val) // die "$val: invalid $name.\n";
+	};
+    };
 
-    Getopt::EX::Hashed->configure( DEFAULT => [] );
+    ### --ambiguous=wide
+    has '+ambiguous' => action => sub {
+	if ($_[1] eq 'wide') {
+	    $Text::VisualWidth::PP::EastAsian = 1;
+	    Text::ANSI::Fold->configure(ambiguous => 'wide');
+	}
+    };
+
+    ### --tabstop, --tabstyle
+    has [ qw(+tabstop +tabstyle) ] => action => sub {
+	my($name, $val) = map "$_", @_;
+	Text::ANSI::Fold->configure($name => $val);
+    };
+
+    ### --tabhead, --tabspace
+    use charnames ':loose';
+    has [ qw(+tabhead +tabspace) ] => action => sub {
+	my($name, $c) = map "$_", @_;
+	$c = charnames::string_vianame($c) || die "$c: invalid name\n"
+	    if length($c) > 1;
+	Text::ANSI::Fold->configure($name => $c);
+    };
 
     has TERM_SIZE           => ;
     has COLORHASH           => default => {};
@@ -128,17 +161,6 @@ sub setup_options {
 	$obj->{border} = 1;
     }
 
-    ## RPN calc for --height, --width, --pane-width
-    for my $param ([ 'height',      $obj->term_height ],
-		   [ 'width',       $obj->term_width  ],
-		   [ 'pane_width',  $obj->term_width  ]) {
-	my($name, @stack) = @$param;
-	my $exp = $obj->{$name} or next;
-	$exp =~ /\D/ or next;
-	$obj->{$name} = rpn_calc(@stack, $exp)
-	    or die "$exp: invalid $name.\n";
-    }
-
     ## --linestyle
     if ($obj->linestyle eq 'wordwrap') {
 	$obj->{linestyle} = 'wrap';
@@ -178,30 +200,6 @@ sub setup_options {
 	    ->style($style) // die "$style: Unknown style.\n";
     }
 
-    ## --ambiguous=wide
-    if ($obj->ambiguous eq 'wide') {
-	$Text::VisualWidth::PP::EastAsian = 1;
-	Text::ANSI::Fold->configure(ambiguous => 'wide');
-    }
-
-    ## --tabstop, --tabstyle
-    for my $opt (qw(tabstop tabstyle)) {
-	if (my $v = $obj->{$opt}) {
-	    Text::ANSI::Fold->configure($opt => $v);
-	}
-    }
-
-    ## --tabhead, --tabspace
-    use charnames ':loose';
-    for my $opt (qw(tabhead tabspace)) {
-	for ($obj->{$opt}) {
-	    defined && length or next;
-	    $_ = charnames::string_vianame($_) || die "$_: invalid name\n"
-		if length > 1;
-	    Text::ANSI::Fold->configure($opt => $_);
-	}
-    }
-
     $obj;
 }
 
