@@ -50,29 +50,28 @@ my %template = (
     line => {
 	center => "│ ", # "\x{2502} "
     },
-    heavy_line => {
-	center => "┃ ", # "\x{2503} "
+    fat_line => {
+	center => [ "█ ", "░ " ], # "\x{2588} "
     },
     vbar => {
 	center => [ "╷ "  , # "\x{2577} "
 		    "│ "  , # "\x{2502} "
 		    "╵ " ], # "\x{2575} "
     },
-    heavy_vbar => {
-	center => [ "╻ "  , # "\x{257b} "
-		    "┃ "  , # "\x{2503} "
-		    "╹ " ], # "\x{2579} "
+    thick_vbar => {
+	center => [ "▗ "  , # "\x{2597} "
+		    "▐ "  , # "\x{2590} "
+		    "▝ " ], # "\x{259D} "
     },
-    fence => {
-	left   => [ "╷ "  , # "\x{2577} "
+    fat_vbar => {
+	center => [ "▄ "  , # "\x{2584} "
+		    "█ "  , # "\x{2588} "
+		    "▀ " ], # "\x{2580} "
+    },
+    stick => {
+	center => [ "╻ "  , # "\x{2577} "
 		    "│ "  , # "\x{2502} "
-		    "╵ " ], # "\x{2575} "
-	center => [ "╷ "  , # "\x{2577} "
-		    "│ "  , # "\x{2502} "
-		    "╵ " ], # "\x{2575} "
-	right  => [ "╷"   , # "\x{2577} "
-		    "│"   , # "\x{2502} "
-		    "╵"  ], # "\x{2575} "
+		    "╹ " ], # "\x{2575} "
     },
     ascii_frame => {
 	top    => "-",
@@ -98,7 +97,7 @@ my %template = (
 			  ' */' ],
 	bottom       =>   '*',
     },
-    c_box_2 => {
+    c_box2 => {
 	top          =>   '*',
 	left         => [ '/**',
 			  ' * ',
@@ -189,6 +188,58 @@ my %template = (
 		    "▄▟" ],
 	bottom =>   "▄",
     },
+    fat_box => {
+	top    =>   "▀",
+	left   => [ "█▀"  ,
+		    "█ "  ,
+		    "█▄" ],
+	center => [ "▀█ █▀"  ,
+		    " █ █ "  ,
+		    "▄█ █▄" ],
+	right  => [ "▀█" ,
+		    " █" ,
+		    "▄█" ],
+	bottom =>   "▄",
+    },
+    very_fat_box => {
+	top    =>   "█",
+	left   => [ "███"  ,
+		    "██ "  ,
+		    "███" ],
+	center => [ "███  ███"  ,
+		    " ██  ██ "  ,
+		    "███  ███" ],
+	right  => [ "███" ,
+		    " ██" ,
+		    "███" ],
+	bottom =>   "█",
+    },
+    fat_frame => {
+	top    =>   "▀",
+	left   => [ "█▀"  ,
+		    "█ "  ,
+		    "█▄" ],
+	center => [ "▀█▀"  ,
+		    " █ "  ,
+		    "▄█▄" ],
+	right  => [ "▀█" ,
+		    " █" ,
+		    "▄█" ],
+	bottom =>   "▄",
+    },
+    very_fat_frame => {
+	top    =>   "█",
+	left   => [ "███"  ,
+		    "██ "  ,
+		    "███" ],
+	center => [ "████"  ,
+		    " ██ "  ,
+		    "████" ],
+	right  => [ "███" ,
+		    " ██" ,
+		    "███" ],
+	bottom =>   "█",
+    },
     comb => {
 	top    =>    "─",
 	left   => [ "┌─"  ,
@@ -225,7 +276,7 @@ my %template = (
 		    "┤" ],
 	bottom =>   "─",
     },
-    mesh2 => {
+    hsem => {
 	top    =>   "─",
 	left   => [ "├"  ,
 		    "│"  ,
@@ -242,11 +293,6 @@ my %template = (
 		    "│ "  , # "\x{2502} "
 		    "▀ " ], # "\x{2580} "
     },
-    heavy_dumbbell => {
-	center => [ "▄ "  , # "\x{2584} "
-		    "┃ "  , # "\x{2503} "
-		    "▀ " ], # "\x{2580} "
-    },
     ribbon => {
 	center => [ "┌┐ "  , # "\x{250c}\x{2510}"
 		    "││ "  , # "\x{2502}\x{2502}"
@@ -254,37 +300,33 @@ my %template = (
 	left => ' ',
     },
     round_ribbon => {
-	center => [ "╭╮"  , # "\x{256D}\x{256E}"
-		    "││"  , # "\x{2502}\x{2502}"
-		    "╰╯" ], # "\x{2570}\x{256F}"
+	center => [ "╭╮ "  , # "\x{256D}\x{256E}"
+		    "││ "  , # "\x{2502}\x{2502}"
+		    "╰╯ " ], # "\x{2570}\x{256F}"
     },
     double_ribbon => {
-	center => [ "╒╕"  , # "\x{2552}\x{2555}"
-		    "││"  , # "\x{2502}\x{2502}"
-		    "╘╛" ], # "\x{2558}\x{255B}"
-    },
-    double_double_ribbon => {
-	center => [ "╔╗"  , # "\x{2554}\x{2557}"
-		    "║║"  , # "\x{2551}\x{2551}"
-		    "╚╝" ], # "\x{255A}\x{255D}"
-    },
-    heavy_ribbon => {
-	center => [ "┏┓"  , # "\x{250F}\x{2513}"
-		    "┃┃"  , # "\x{2503}\x{2503}"
-		    "┗┛" ], # "\x{2517}\x{251B}"
-    },
-    block_element => {
-	center => [ "▄ "  , # "\x{2584} "
-		    "█ "  , # "\x{2588} "
-		    "▀ " ], # "\x{2580} "
-    },
-    block_element_half => {
-	center => [ "▗ "  , # "\x{2597} "
-		    "▐ "  , # "\x{2590} "
-		    "▝ " ], # "\x{259D} "
+	center => [ "╔╗ "  , # "\x{2554}\x{2557}"
+		    "║║ "  , # "\x{2551}\x{2551}"
+		    "╚╝ " ], # "\x{255A}\x{255D}"
     },
     );
 
+use Clone qw(clone);
+
+for my $style (qw(line vbar box round_box shadow_box frame page_frame comb rake mesh mesh2
+		  dumbbell ribbon)) {
+    my $new = $template{"heavy_$style"} = clone $template{$style};
+    while (my($k, $v) = each %$new) {
+	for (ref $v ? @$v : $new->{$k}) {
+	    $_ = heavy($_);
+	}
+    }
+}
+
+sub heavy {
+    $_[0] =~ tr[─│┌┐└┘├┤┬┴┼╴╵╶╷][━┃┏┓┗┛┣┫┳┻╋╸╹╺╻]r;
+}
+
 sub new {
     my $class = shift;
     my $style = @_ ? shift : 'DEFAULT';
